`timescale 1ns / 1ps

module top_level( input clk,				//100MHz input from onboard can oscillator
						input cpuRST,					//active high reset input for 65Org16 core
					   output [15:0] cpuDO,			//cpu databus out for analyzing in Xilinx ISIM
					   output [31:0] cpuAB,			//cpu addressbus
					   output cpuWE					//cpu WE
					   //output CLKout					//main clock to offboard ICs like videoDAC and syncRAM
					   );

//internal cpu signals
	wire [15:0] cpuDI;
	//wire clk;
	
//internal blockRAM signals
	wire [15:0] ram1DO;								//1Kx16 blockRAM synchronous output for 65org16 core zero page
	wire [15:0] ram2DO;								//1Kx16 blockRAM synchronous output for 65Org16 core stack page
	wire [15:0] rom1DO;								//4Kx16 blockRAM synchronous output for 65Org16 core ROM
	wire ram1CS;
	wire ram1WE;
	wire ram2CS;
	wire ram2WE;
	wire rom1CS;
	
	//MainCLK XLXI_1 (.CLK_IN1(MAINCLK1), 
   //                .CLK_OUT1(clk),
	//					 .cpuRST(cpuRST));
						  
	//ClkOutDDRFF XLXI_2 (.CE(1'b1), 
   //                    .SigIn(clk), 
   //                    .SigOut(CLKout));
								
	cpu XLXI_3 (.clk(clk),
					.reset(cpuRST),
					.AB(cpuAB),
					.DI(cpuDI),
					.DO(cpuDO),
					.WE(cpuWE),
					.IRQ(1'b0),
					.NMI(1'b0),
					.RDY(1'b1));
					
   SRAMif  XLXI_4 (.cpuWE(cpuWE),
						 .cpuAB(cpuAB),
						 .ram1CS(ram1CS),
						 .ram1WE(ram1WE),
						 .ram2CS(ram2CS),
						 .ram2WE(ram2WE),
						 .rom1CS(rom1CS));
						
	ZPRAM XLXI_5 (.clk(clk),
					  .we(ram1WE),
					  .rst(ram1CS),
					  .addr(cpuAB [9:0]),
					  .din(cpuDO),
					  .dout(ram1DO));
					 
	STRAM XLXI_6 (.clk(clk),					  
					  .we(ram2WE),
					  .rst(ram2CS),
					  .addr(cpuAB [9:0]),
					  .din(cpuDO),
					  .dout(ram2DO));
					 
	SYSROM XLXI_7 (.clk(clk),
					   .rst(rom1CS),
					   .addr(cpuAB [11:0]),
					   .dout(rom1DO));
						
	ORs XLXI_8 (.ram1DO(ram1DO),
					.ram2DO(ram2DO),
					.rom1DO(rom1DO),
					.cpuDI(cpuDI));
					 	
endmodule
